==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/he.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "הפעולה שצוינה שגויה",
    "The given regular expression is invalid" : "הביטוי הרגולרי שצוין שגוי",
    "The given file size is invalid" : "גודל הקובץ שצוין שגוי",
    "The given tag id is invalid" : "התגית שצוינה שגויה",
    "The given IP range is invalid" : "טווח כתובות ה־IP שצוין שגוי",
    "The given IP range is not valid for IPv4" : "טווח כתובות ה־IP שצוין אינו תקף ל־IPv4",
    "The given IP range is not valid for IPv6" : "טווח כתובות ה־IP שצוין אינו תקף ל־IPv6",
    "The given time span is invalid" : "טווח הזמן שצוין שגוי",
    "The given start time is invalid" : "מועד ההתחלה שצוין שגוי",
    "The given end time is invalid" : "מועד הסיום שצוין שגוי",
    "The given group does not exist" : "הקבוצה שצוינה אינה קיימת",
    "Operation #%s does not exist" : "פעולה מס׳ %s לא קיימת",
    "Operation %s does not exist" : "הפעולה %s לא קיימת",
    "Operation %s is invalid" : "הפעולה %s שגויה",
    "Predefined URLs" : "כתובות שמוגדרות מראש",
    "Files WebDAV" : "WebDAV קבצים",
    "Android client" : "לקוח Android",
    "iOS client" : "לקוח iOS",
    "Desktop client" : "לקוח שולחן עבודה",
    "Thunderbird & Outlook addons" : "תוספות ל־Thunderbird ול־Outlook",
    "Save" : "שמירה",
    "File name" : "שם קובץ",
    "is" : "הוא",
    "is not" : "אינו",
    "matches" : "תואם",
    "does not match" : "אינו תואם",
    "File MIME type" : "סוג ה־MIME של הקובץ",
    "File size (upload)" : "גודל קובץ (העלאה)",
    "less" : "פחות",
    "less or equals" : "פחות או שווה",
    "greater or equals" : "גדול או שווה",
    "greater" : "גדול",
    "Request remote address" : "בקשת כתובת מרוחקת",
    "matches IPv4" : "התאמת IPv4",
    "does not match IPv4" : "ללא התאמת IPv4",
    "matches IPv6" : "התאמת IPv6",
    "does not match IPv6" : "ללא התאמת IPv6",
    "File system tag" : "תגית מערכת קבצים",
    "is tagged with" : "עם התגית",
    "is not tagged with" : "ללא התגית",
    "Request URL" : "כתובת בקשה",
    "Request time" : "זמן בקשה",
    "between" : "בין",
    "not between" : "לא בין",
    "Request user agent" : "סוכן משתמש הבקשה",
    "User group membership" : "חברות בקבוצת משתמשים",
    "is member of" : "חבר בקבוצה",
    "is not member of" : "לא חבר בקבוצה",
    "Short rule description" : "תיאור מקוצר לכלל",
    "Add rule" : "הוספת כלל",
    "Reset" : "איפוס",
    "Saving…" : "בהליכי שמירה…",
    "Group list is empty" : "רשימת הקבוצות ריקה",
    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
    "Saved" : "נשמרה",
    "Saving failed:" : "השמירה נכשלה:",
    "Add rule group" : "הוספת קבוצת כללים",
    "Example: {placeholder}" : "דוגמה: {placeholder}",
    "Select tag…" : "בחירת תגית…",
    "Start" : "התחלה",
    "End" : "סיום",
    "Select timezone…" : "בחירת אזור זמן…",
    "Sync clients" : "סנכרון לקוחות",
    "Open documentation" : "פתיחת תיעוד",
    "Loading…" : "בטעינה…",
    "Tag management" : "ניהול תגיות"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/he.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "הפעולה שצוינה שגויה",
    "The given regular expression is invalid" : "הביטוי הרגולרי שצוין שגוי",
    "The given file size is invalid" : "גודל הקובץ שצוין שגוי",
    "The given tag id is invalid" : "התגית שצוינה שגויה",
    "The given IP range is invalid" : "טווח כתובות ה־IP שצוין שגוי",
    "The given IP range is not valid for IPv4" : "טווח כתובות ה־IP שצוין אינו תקף ל־IPv4",
    "The given IP range is not valid for IPv6" : "טווח כתובות ה־IP שצוין אינו תקף ל־IPv6",
    "The given time span is invalid" : "טווח הזמן שצוין שגוי",
    "The given start time is invalid" : "מועד ההתחלה שצוין שגוי",
    "The given end time is invalid" : "מועד הסיום שצוין שגוי",
    "The given group does not exist" : "הקבוצה שצוינה אינה קיימת",
    "File" : "קובץ",
    "Operation #%s does not exist" : "פעולה מס׳ %s לא קיימת",
    "Operation %s does not exist" : "הפעולה %s לא קיימת",
    "Operation %s is invalid" : "הפעולה %s שגויה",
    "Images" : "תמונות",
    "No results" : "אין תוצאות",
    "%s (invisible)" : "%s (נסתר)",
    "%s (restricted)" : "%s (מוגבל)",
    "Predefined URLs" : "כתובות שמוגדרות מראש",
    "Files WebDAV" : "WebDAV קבצים",
    "Android client" : "לקוח Android",
    "iOS client" : "לקוח iOS",
    "Desktop client" : "לקוח שולחן עבודה",
    "Thunderbird & Outlook addons" : "תוספות ל־Thunderbird ול־Outlook",
    "Cancel" : "ביטול",
    "Delete" : "מחיקה",
    "Active" : "פעיל",
    "Save" : "שמירה",
    "Browse the app store" : "עיון בחנות היישומונים",
    "matches" : "תואם",
    "does not match" : "אינו תואם",
    "is" : "הוא",
    "is not" : "אינו",
    "File name" : "שם קובץ",
    "File MIME type" : "סוג ה־MIME של הקובץ",
    "File size (upload)" : "גודל קובץ (העלאה)",
    "less" : "פחות",
    "less or equals" : "פחות או שווה",
    "greater or equals" : "גדול או שווה",
    "greater" : "גדול",
    "Request remote address" : "בקשת כתובת מרוחקת",
    "matches IPv4" : "התאמת IPv4",
    "does not match IPv4" : "ללא התאמת IPv4",
    "matches IPv6" : "התאמת IPv6",
    "does not match IPv6" : "ללא התאמת IPv6",
    "File system tag" : "תגית מערכת קבצים",
    "is tagged with" : "עם התגית",
    "is not tagged with" : "ללא התגית",
    "Request URL" : "כתובת בקשה",
    "Request time" : "זמן בקשה",
    "between" : "בין",
    "not between" : "לא בין",
    "Request user agent" : "סוכן משתמש הבקשה",
    "User group membership" : "חברות בקבוצת משתמשים",
    "is member of" : "חבר בקבוצה",
    "is not member of" : "לא חבר בקבוצה",
    "Short rule description" : "תיאור מקוצר לכלל",
    "Add rule" : "הוספת כלל",
    "Reset" : "איפוס",
    "Saving…" : "בהליכי שמירה…",
    "Group list is empty" : "רשימת הקבוצות ריקה",
    "Unable to retrieve the group list" : "לא ניתן לקבל את רשימת הקבוצות",
    "Saved" : "נשמרה",
    "Saving failed:" : "השמירה נכשלה:",
    "Add rule group" : "הוספת קבוצת כללים",
    "Example: {placeholder}" : "דוגמה: {placeholder}",
    "Select tag…" : "בחירת תגית…",
    "Start" : "התחלה",
    "End" : "סיום",
    "Select timezone…" : "בחירת אזור זמן…",
    "Sync clients" : "סנכרון לקוחות",
    "Open documentation" : "פתיחת תיעוד",
    "Loading…" : "בטעינה…",
    "Tag management" : "ניהול תגיות"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
